+++
title = "HCC Class Info for Students"
description = "Information for students taking class using HCC resources"
weight = "95"
+++

The Holland Computing Center (HCC) provides high-performance computing resources for Universities and Colleges in the state of Nebraska. HCC supports both research and creative, and class activity.


This guide provides a list of useful links for classes utilizing HCC resources.


## Useful links for students

### Account creation and setup
- New user account form, https://hcc.unl.edu/new-user-request/
- If you already have existing HCC account, use the Add/Change group request form instead, https://hcc.unl.edu/group-addchange-request
- How to activate HCC Duo, https://hcc.unl.edu/docs/accounts/setting_up_and_using_duo/
- How to reset your HCC password, https://hcc.unl.edu/docs/accounts/how_to_change_your_password/
- What are good HCC practices, https://hcc.unl.edu/docs/good_hcc_practices/

### Application links
- HCC Open OnDemand (OOD) web access to Swan, https://swan-ood.unl.edu/
- Detailed HCC Open OnDemand guide, https://hcc.unl.edu/docs/open_ondemand/
- Creating custom CPU/GPU conda environments, https://hcc.unl.edu/docs/applications/user_software/using_anaconda_package_manager/#creating-custom-anaconda-environments
- Various SLURM examples of applications that run on Swan, https://github.com/unlhcc/job-examples/
- How to share data across group members, https://hcc.unl.edu/docs/handling_data/swan_data_sharing/

### Training
- HCC info sheet, https://go.unl.edu/hcc_info_sheet
- HCC SLURM scheduler cheat sheet, https://go.unl.edu/hcc_slurm_cheatsheet
- Conda user cheat sheet, https://know.continuum.io/rs/387-XNW-688/images/conda-cheatsheet.pdf
- YouTube videos of previous HCC training events, https://www.youtube.com/@hollandcomputingcenter8962
- Upcoming HCC events, https://hcc.unl.edu/upcoming-events

### Support
- For issues related to classwork or assignments, **please contact your TA**.
- For general HCC issues, **please first check the FAQ page**, https://hcc.unl.edu/docs/faq/.
- For issues with HCC resources (e.g., unavailable resources, sudden errors and job failures), contact HCC support at hcc-support@unl.edu. **Please note that non-critical tickets/issues will be addressed during business hours (Monday through Friday, 9am-5pm CST).** Critical issues include, but not limited to, sudden unavailability to login and file-system irresponsiveness for all HCC users.


## Useful notes for students
- The **login node** is shared among all HCC users and it **should be used only for light tasks**, and not for running computationally intensive tasks. For any CPU or memory intensive operations, such as testing and running applications, one should use an interactive session (https://hcc.unl.edu/docs/submitting_jobs/creating_an_interactive_job/), or submit a job to the batch queue (https://hcc.unl.edu/docs/submitting_jobs/). 
- If the Open OnDemand resources are not enough, you can run JupyterLab Notebooks within SLURM job, https://hcc.unl.edu/docs/applications/submitting_jupyter_code/running_jupyter_lab_code.
- Custom conda environments are created in $HOME by default. **You can change the location of the conda environment**, https://hcc.unl.edu/docs/applications/user_software/using_anaconda_package_manager/#using-common-for-environments/.
- Custom conda environments can easily fill the 20GBs quota on $HOME. **To clean space, you can remove unused Anaconda packages and caches**, https://hcc.unl.edu/docs/applications/user_software/using_anaconda_package_manager/#remove-unused-anaconda-packages-and-caches.
- Open OnDemand can not be launched and will show error **if your $HOME quota is exceeded**.
- If you are not sure if the storage utilization is causing issues for you, you can run `ncdu` (https://hcc.unl.edu/docs/faq/#how-can-i-check-which-directories-utilize-the-most-storage-on-swan) from the Swan terminal with the location in question.
