+++
title = "I have an HCC account, now what?"
description = "Information after getting a new HCC account"
weight = "95"
+++

- [Important links and information](#important-links-and-information)
    - [HCC Support](#hcc-support)
    - [HCC Resource Status](#hcc-resource-status)
    - [Data Storage](#data-storage)
- [Getting started running jobs on HCC resources.](#getting-started-running-jobs-on-hcc-resources)
- [Account 2FA and Password](#account-2fa-and-password)
    - [I forgot my password, how can I retrieve it?](#i-forgot-my-password-how-can-i-retrieve-it)
    - [If I get a new phone, how do I (re)activate Duo?](#if-i-get-a-new-phone-how-do-i-reactivate-duo)

---

#### I have requested an account, what are my next steps?

Once you request an account, HCC staff will wait for a confirmation from either your instructor or lab group advisor. 

When HCC recieves this confirmation, your account will be created. A temporary password will be sent to your email.

However you will still not be able to sign in just yet. First you will need to setup our multifactor authentication. 

- If you are a part of the NU System (UNL, UNO, UNK, UNMC), HCC will ask if you would like to use the phone number tied to your TrueYou account. Once you confirm this number, HCC staff will have a text message sent by DUO to activate your multifactor with HCC resources.
  
- If you are not a part of the NU system or wish to use a different phone number than what is in TrueYou, you will need to attend one of our remote office hours where an HCC staff will assist you. 

- If you do not wish to use your smartphone to authenticate with HCC resources, you can use a YubiKey with HCC resources. More information on YubiKeys is available [here]({{< relref "../accounts/setting_up_and_using_duo/#yubikeys" >}})

It is strongly recommended to [change your password]({{< relref "../accounts/how_to_change_your_password" >}}) as soon as possible.

At this point, you can now connect to and begin using HCC resources.

#### How do I connect to HCC resources?

Congrats on getting an HCC account! Now you need to connect to an HCC resource.
To do this, we can use an SSH connection or we can use a web browser to access the online web portal, Open OnDemand.
Both methods allows you to securely connect to a remote HCC resource and
operate it just like you would a personal machine.

Check out our documentation on [Connecting to HCC Clusters using SSH]
({{< relref "../connecting/" >}}) and on [using Open OnDemand]({{< relref "../open_ondemand/" >}}).


## Important links and information

#### HCC Support

- **Real time and email support**
We have an open door policy and invite you to join our [Remote Open Office hours](https://hcc.unl.edu/OOH), schedule a remote or in-person session at [hcc-support@unl.edu](mailto:hcc-support@unl.edu), or you can drop one of us a line and we'll arrange a time to meet:  [Contact Us](https://hcc.unl.edu/contact-us).

- **Class and group tutorial and introduction sessions**
If your class or group is interested in a introductory session, please [email us](mailto:hcc-support@unl.edu) and we will work to schedule a time. 

- **Training events**
We also host training events throughout the year that are announced via email to all with HCC accounts and viewable on our [Upcoming Events](https://hcc.unl.edu/upcoming-events) page. Our materials are also available for prior events on our [Past Events](https://hcc.unl.edu/past-events) page.

- **HCC Courses**
In addition to live events, we also have courses available using Bridge available on our [HCC Courses](https://hcc.unl.edu/hcc-courses) page.

#### HCC Resource Status

From time to time, HCC resources may be unavailable due to scheduled maintenance or unforseen issues. Upcoming maintenance will be announced ahead of time on the [status page](https://status.hcc.unl.edu/) and via email. Any unforseen issues will be posted to the [status page](https://status.hcc.unl.edu/) once HCC staff have established the issue. 

#### Data Storage

- **Where to store data:** HCC has 5 filesystems available for use. Specific details on the file systems are available on our [data storage documentation.]({{< relref "../handling_data/data_storage/" >}}) 

- **Key information:** The main information to take note is that the Common, Work, and NRDStor filesystems do not have any backups. Any files deleted on these filesystems are **permanently lost**. 

- **Purge policy:** The Work filesystem also has a purge policy in place to delete old and unused files to keep the file system performant. There is **no** purge policy on Attic, Home, Common, or NRDStor. 

Attic and Home are the only file systems with backups available.

- **Preventing file loss:** It is _**critical**_ to backup any important data related to your class, creative, or research activities. HCC provides a [guide]({{< relref "../handling_data/data_storage/preventing_file_loss/" >}}) on how to backup important data and prevent file loss. 


## Getting started running jobs on HCC resources. 

Once you have your account setup and reviewed the important information above, you can begin conducting class, creative, or research activities on HCC resources. 

For Swan, you will need to take a few steps. 

1. [Transfer data to HCC Clusters]({{< relref "../handling_data/" >}})
   
2. [Check software availability]({{< relref "../applications/" >}})
   
3. [Submit jobs on HCC Clusters]({{< relref "../submitting_jobs/" >}}) or use [Open OnDemand]({{< relref "../open_ondemand/" >}})






## Account 2FA and Password

#### I forgot my password, how can I retrieve it?

Information on how to change or retrieve your password can be found on
the documentation page: [How to change your
password]({{< relref "/accounts/how_to_change_your_password" >}})


All passwords must be at least 8 characters in length and must contain
at least one capital letter and one numeric digit. Passwords also cannot
contain any dictionary words. If you need help picking a good password,
consider using a (secure!) password generator such as
[this one provided by Random.org](https://www.random.org/passwords)

To preserve the security of your account, we recommend changing the
default password you were given as soon as possible.

#### If I get a new phone, how do I (re)activate Duo?

**If you have not activated Duo before:**

If you are a part of the NU System, email us at {{< icon name="envelope" >}}[hcc-support@unl.edu](mailto:hcc-support@unl.edu)
from the email address your account is registered under and send the last 4 digits of your phone number and we will send you a link that you can use to activate Duo.

Please join our [Remote Open Office hours](https://hcc.unl.edu/OOH) or schedule another remote 
session at [hcc-support@unl.edu](mailto:hcc-support@unl.edu) and show your photo ID and we will be happy to activate it for you. 

**If you have activated Duo previously but now have a different phone number:**

Join our [Remote Open Office hours](https://hcc.unl.edu/OOH) or schedule another remote 
session at [hcc-support@unl.edu](mailto:hcc-support@unl.edu) and show your photo ID and we will be happy to activate it for you. 

**If you have activated Duo previously and have the same phone number:**

Email us at {{< icon name="envelope" >}}[hcc-support@unl.edu](mailto:hcc-support@unl.edu)
from the email address your account is registered under and we will send
you a new link that you can use to activate Duo.


