+++
title = "Running SAS on HCC"
description = "How to run SAS on HCC resources."
+++


- [Running SAS through the command line](#sas-on-hcc-clusters)
- [Running SAS on HCC OnDemand](#sas-on-hcc-ondemand)

This quick start demonstrates how to use a SAS program on
HCC resources through the command line and HCC OnDemand. The sample code and submit scripts can be
downloaded from [HCC's job-examples git repository](https://github.com/unlhcc/job-examples).

{{% notice info%}}
SAS is licensed software, and SAS on HCC resources is supported under UNL system-wide SAS license.
If you are part of UNL and would like to use SAS on HCC during the subscription period, please contact hcc-support@unl.edu to request access.
{{% /notice %}}



## SAS on HCC Clusters
SAS applications can be run on HCC clusters similar to other jobs.
[Connect to an HCC cluster]({{< relref "../../connecting/" >}}) and make a subdirectory 
called `sas_demo` under your `$WORK` directory. 

In the subdirectory `sas_demo`, save the SAS code. Here, we include a single demo
programs, `t_test.sas`, to perform a t-test analysis on a small data set. 

[t_test.sas](https://raw.githubusercontent.com/unlhcc/job-examples/master/sas/t-test.sas)



---

#### Creating a Submit Script

Create a submit script to request one core (default) and 10 minutes run time
on the supercomputer. The name of the main program is entered at the last
line.

[sas.submit](https://raw.githubusercontent.com/unlhcc/job-examples/master/sas/sas.submit)

#### Submit the Job

The job can be submitted through the command `sbatch`. The job status
can be monitored by entering `squeue` with the `-u` option.

{{< highlight bash >}}
$ sbatch sas.submit
$ squeue -u <username>
{{< /highlight >}}

Replace `<username>` with your HCC username.

#### Sample Output

The results of the t-test are computed and printed to the `.lst` file 



## SAS on HCC OnDemand
On [HCC OnDemand]({{< relref "../../open_ondemand/connecting_to_hcc_ondemand/" >}}), SAS can be accessed via Jupyter Lab Notebook and dedicated SAS Interactive GUI Application, visible for researchers with valid SAS license.

### SAS on Jupyter Lab
[Launch a Jupyter Lab Notebook session]({{< relref "../../open_ondemand/virtual_desktop_and_interactive_apps/" >}}). After the Jupyter Lab Notebook session starts, select `SAS` from the `New` dropdown box. 
{{< figure src="/images/jupyterNew.png" >}}
Here, you can run code in the Notebook's cells. The SAS code is then executed when you click on the "play" icon or press the `shift` and `enter` keys simultaneously. 
{{< figure src="/images/jupyter_sas_code.png" >}}

### SAS Interactive GUI Application
[Launch the Interactive App]({{< relref "../../open_ondemand/virtual_desktop_and_interactive_apps/" >}}) by selecting `SAS` from the `Interactive Apps` drop-down menu at the top of the OnDemand Dashboard page and filling in the parameters needed for your job.
{{< figure src="/images/sas_1.png" >}}
SAS scripts can then be run from the Editor, and the results will be shown in a browser.
{{< figure src="/images/sas_2.png" >}}

