+++
title = "Using Preinstalled Software"
description = "How to use the module utility on HCC resources."
weight=10
+++

HCC offers many popular software packages already installed. Unlike a traditional
laptop or desktop, HCC resources use a module system for managing installed software. Users can load and
use pre-installed software by using the `module` command.

To request additional software installs, please complete a [software installation request]
(https://hcc.unl.edu/software-installation-request).

`module` commands provide an HPC system user the capability to compile
into their source code using any type of library that is
available on the server. The `module` command gives each user the
ability to modify their environmental `PATH` and `LD_LIBRARY_PATH`
variables.

{{% notice info %}}
Please note that if you compile your application using a particular
module, you must include the appropriate module load statement in your
submit script.
{{% /notice %}}

### List Modules Loaded

{{% panel theme="info" header="Example Usage: module list" %}}
{{< highlight bash >}}
module list

No Modulefiles Currently Loaded.
 
echo $PATH
/usr/lib64/qt-3.3/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin
{{< /highlight >}}
{{% /panel %}}


### List Modules Available


{{% panel theme="info" header="Example Usage: Listing Available Modules" %}}
{{< highlight bash >}}
module avail

---------------------------------------------- /util/opt/Modules/modulefiles ----------------------------------------------
NCL/6.0             bowtie/2.0.0-beta6  compiler/pgi/12     hdfeos5/1.14        mplus/7.0           szip/2.1            
NCL/6.0dist         compiler/gcc/4.6    cufflinks/2.0.2     hugeseq/1.0         netcdf/4.1          tophat/2.0.5        
NCO/4.1             compiler/gcc/4.7    deprecated          intel-mkl/11        netcdf/4.2          udunits/2.1         
R/2.15              compiler/intel/11   hdf4/4.2            intel-mkl/12        openmpi/1.5         zlib/1.2            
WRF/WRF             compiler/intel/12   hdf5/1.8            lsdyna/5.1.1        openmpi/1.6         
acml/5.1            compiler/open64/4.5 hdf5/1.8.6          lsdyna/6.0.0        samtools/0.1        
bowtie/0.12.8       compiler/pgi/11     hdfeos2/2.18        mplus/6.12          sas/9.3    
{{< /highlight >}}
{{% /panel %}}

#### module load \<module-name\>

Places the binaries and libraries for \<module-name\> into your `PATH` and `LD_LIBRARY_PATH`.

{{% panel theme="info" header="Example Usage: Loading Desired Module" %}}
{{< highlight bash >}} 
module load compiler/pgi/11
 
module list
Currently Loaded Modulefiles:
 1) compiler/pgi/11 

echo $PATH
/util/comp/pgi/linux86-64/11/bin:/usr/lib64/qt-3.3/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin
{{< /highlight >}}
{{% /panel %}}

#### module unload \<module-name\>

Removes the binaries and libraries associated with \<module-name\> from your PATH and `LD_LIBRARY_PATH`.

{{% panel theme="info" header="Example Usage: module unload" %}}
{{< highlight bash >}}
module unload compiler/pgi/11

module list
No Modulefiles Currently Loaded.

echo $PATH
/usr/lib64/qt-3.3/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin 
{{< /highlight >}}
{{% /panel %}} 

#### module purge

**Purges** all previously **loaded** module libraries and binaries from
your `PATH` and `LD_LIBRARY_PATH`.

{{% panel theme="info" header="Example Usage: module purge" %}}
{{< highlight bash >}}
module load compiler/open64
module load zlib/1.2


module list


Currently Loaded Modulefiles:
 1) zlib/1.2             2) compiler/open64/4.5 


module purge


module list

No Modulefiles Currently Loaded.
{{< /highlight >}}
{{% /panel %}}

#### module help

To see a complete list of module commands/options.

**Example Usage: module help**

{{% panel theme="info" header="Example Usage: module help" %}}
{{< highlight bash >}}
Usage: module [options] sub-command [args ...]

Options:
  -h -? -H --help                   This help message
  -s availStyle --style=availStyle  Site controlled avail style: system en_grouped (default: en_grouped)
  --regression_testing              Lmod regression testing
  -D                                Program tracing written to stderr
  --debug=dbglvl                    Program tracing written to stderr
  --pin_versions=pinVersions        When doing a restore use specified version, do not follow defaults
  -d --default                      List default modules only when used with avail
  -q --quiet                        Do not print out warnings
  --expert                          Expert mode
  -t --terse                        Write out in machine readable format for commands: list, avail, spider, savelist
  --initial_load                    loading Lmod for first time in a user shell
  --latest                          Load latest (ignore default)
  --ignore_cache                    Treat the cache file(s) as out-of-date
  --novice                          Turn off expert and quiet flag
  --raw                             Print modulefile in raw output when used with show
  -w twidth --width=twidth          Use this as max term width
  -v --version                      Print version info and quit
  -r --regexp                       use regular expression match
  --gitversion                      Dump git version in a machine readable way and quit
  --dumpversion                     Dump version in a machine readable way and quit
  --check_syntax --checkSyntax      Checking module command syntax: do not load
  --config                          Report Lmod Configuration
  --config_json                     Report Lmod Configuration in json format
  --mt                              Report Module Table State
  --timer                           report run times
  --force                           force removal of a sticky module or save an empty collection
  --redirect                        Send the output of list, avail, spider to stdout (not stderr)
  --no_redirect                     Force output of list, avail and spider to stderr
  --show_hidden                     Avail and spider will report hidden modules
  --spider_timeout=timeout          a timeout for spider
  -T --trace

module [options] sub-command [args ...]

Help sub-commands:
------------------
  help                              prints this message
  help                module [...]  print help message from module(s)

Loading/Unloading sub-commands:
-------------------------------
  load | add          module [...]  load module(s)
  try-load | try-add  module [...]  Add module(s), do not complain if not found
  del | unload        module [...]  Remove module(s), do not complain if not found
  swap | sw | switch  m1 m2         unload m1 and load m2
  purge                             unload all modules
  refresh                           reload aliases from current list of modules.
  update                            reload all currently loaded modules.

Listing / Searching sub-commands:
---------------------------------
  list                              List loaded modules
  list                s1 s2 ...     List loaded modules that match the pattern
  avail | av                        List available modules
  avail | av          string        List available modules that contain "string".
  spider                            List all possible modules
  spider              module        List all possible version of that module file
  spider              string        List all module that contain the "string".
  spider              name/version  Detailed information about that version of the module.
  whatis              module        Print whatis information about module
  keyword | key       string        Search all name and whatis that contain "string".

Searching with Lmod:
--------------------
  All searching (spider, list, avail, keyword) support regular expressions:


  spider -r           '^p'          Finds all the modules that start with `p' or `P'
  spider -r           mpi           Finds all modules that have "mpi" in their name.
  spider -r           'mpi$         Finds all modules that end with "mpi" in their name.

Handling a collection of modules:
--------------------------------
  save | s                          Save the current list of modules to a user defined "default" collection.
  save | s            name          Save the current list of modules to "name" collection.
  reset                             The same as "restore system"
  restore | r                       Restore modules from the user's "default" or system default.
  restore | r         name          Restore modules from "name" collection.
  restore             system        Restore module state to system defaults.
  savelist                          List of saved collections.
  describe | mcc      name          Describe the contents of a module collection.

Deprecated commands:
--------------------
  getdefault          [name]        load name collection of modules or user's "default" if no name given.
                                    ===> Use "restore" instead  <====
  setdefault          [name]        Save current list of modules to name if given, otherwise save as the default list for you the user.
                                    ===> Use "save" instead. <====

Miscellaneous sub-commands:
---------------------------
  show                modulefile    show the commands in the module file.
  use [-a]            path          Prepend or Append path to MODULEPATH.
  unuse               path          remove path from MODULEPATH.
  tablelist                         output list of active modules as a lua table.

Important Environment Variables:
--------------------------------
  LMOD_COLORIZE                     If defined to be "YES" then Lmod prints properties and warning in color.

    -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
Lmod Web Sites

  Documentation:    http://lmod.readthedocs.org
  Github:           https://github.com/TACC/Lmod
  Sourceforge:      https://lmod.sf.net
  TACC Homepage:    https://www.tacc.utexas.edu/research-development/tacc-projects/lmod

  To report a bug please read http://lmod.readthedocs.io/en/latest/075_bug_reporting.html
    -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

Modules based on Lua: Version 7.4.16  2017-05-23 11:10 -05:00
    by Robert McLay mclay@tacc.utexas.edu
{{< /highlight >}}
{{% /panel %}}
