+++
title = "Compiling an OpenMP Application"
description = "How to compile an OpenMP-based application on HCC resources."
weight=20
+++

Compiling an [OpenMP](https://computing.llnl.gov/tutorials/openMP)
application is done with the `-fopenmp` option to GCC and the `-openmp` or
`-qopenmp` option for Intel.  For example, the command could be:

{{< highlight bash >}}
$ gcc -o openmp-app.exe -fopenmp openmp-app.c
{{< /highlight >}}

GCC will perform all of the OpenMP pragmas.

OpenMP applications have OpenMP pragmas like `#pragma omp <options>`

{{< highlight C >}}
#pragma omp parallel for reduction(+: sum) 
  for (i = 0; i<NUM_STEPS; i++) {
    x = 2.0 * (double)i / (double)(NUM_STEPS); /* value of x */
    sum += x * x;
  }
{{< /highlight >}}

An example application code is [integrate_mp.c](/attachments/integrate_mp.c).
Compiling `integrate_mp.c` is done with the `gcc` command:

{{< highlight bash >}}
$ gcc -o integrate_mp.exe -fopenmp integrate_mp.c
{{< /highlight >}}

See [Submitting an OpenMP Job]({{< relref "submitting_an_openmp_job" >}}) for
instructions on how to submit `integrate_mp.exe` to the cluster.
