+++
title = "Basic Linux commands"
description = "Simple commands you'll want to know"
weight = "32"
+++

Basic commands
--------------

###### [[Jump to the Video Tutorial]](#tutorial-video)

Holland clusters all run on the Linux operating system, similarly to how
your personal computer might run Windows or Mac OS. However, unlike
Windows or Mac OS, our systems do not utilize a graphical user interface
where you can use a mouse to navigate and initiate commands. Instead, we
use a command line interface, where the user types in commands which are
then processed and text output is displayed on the screen. The default
shell used is Bash. Bash may seem complicated to learn at first, but
with just a small handful of commands, you can do anything that you
would usually do with a mouse. **In fact, once people become proficient
in Bash, many of them prefer it over graphical interfaces due to its
versatility and performance.**

Below, we have compiled a list of common commands and usage examples.
For a more information, check out one of these references:

-  [Software Carpentry’s "Introduction to the Bash Shell" Lesson](https://eharstad.github.io/shell-novice) - 
   a great walkthrough of the basics of Bash designed for novice users
-  [Linux Users Guide](http://www.comptechdoc.org/os/linux/usersguide) -
   detailed information about the Linux command line and how to utilize
   it
-  [Linux Command Line Cheat Sheet](https://www.cheatography.com/davechild/cheat-sheets/linux-command-line) -
    a quick reference for Linux commands. Offers a PDF version that you
    can print out.
	


Linux Commands Reference List:
------------------------------

|       |                                                                                                                                           |                                                                                                                                                                                                                                                                                                                                                                     |
|-------|-------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `ls`    | list: Lists the files and directories located in the current directory                                                                    | <ul><li>`ls`</li><li>`ls -a`<ul><li>shows all the files in the directory, including hidden ones</li></ul></li><li>`ls -l`<ul><li>shows contents in a list format including information such as file size, file permissions and date the file was modified</li></ul></li><li>`ls *.txt`<ul><li>shows all files in the current directory which end with `.txt`</li></ul></li></ul>|
| `cd`    | change directory: this allows users to navigate in or out of file directories                                                             | <ul><li>`cd <folder path>`</li><li>`cd <folder_name>`<ul><li>navigates into directory `<folder_name>` located in the current directory</li></ul></li><li>`cd ..`<ul><li>navigates out of a directory and into the parent directory</li></ul><li>`cd $HOME` (or `$WORK`)<ul><li>navigates to a user's home (or work) directory</li></ul></li></ul>                                                                                                                              |
| `mv`    | move: used to move a file or directory to another location                                                                                | <ul><li>`mv <current file(s)> <target file(s)>`</li><li>`mv * ../`<ul><li>moves all files from the current directory into the parent directory</li></ul></li><li>`mv <old_filename> <new_filename>`<ul><li>renames the file `<old_filename>` to `<new_filename>`</li></ul></li></ul>                                                                                                                                           |
| `cp`    | copy: used to copy a file or directory to another location                                                                                | <ul><li>`cp <current file(s)> <target file(s)>`</li><li>`cp * ../`<ul><li>copies all files in the current directory and puts the copies into the parent directory</li></ul></li><li>`cp -r ./orig_folder ./new_folder`<br /><ul><li>copies all files and directories within `orig_folder` into `new_folder` (`-r` indicates this is a recursive copy, so all sub-directories and files within `orig_folder` will be included in `new_folder`)</li></ul></li></ul> |
| `man`   | manual: displays documentation for commands </br> </br>**Note:** Use up and down arrows to scroll through the text. To exit the manual display, press 'q' | <ul><li>`man <command name>`</li><li>`man ls`<ul><li>displays documentation for the `ls` command</li></ul></li></ul>                                                                                                                                                                                                                                                                                                  |
| `mkdir` | make directory: creates a directory with the specified name                                                                               | <ul><li>`mkdir new_folder`<ul><li>creates the directory `new_folder` within the current directory</li></ul></li></ul>                                                                                                                                                                                                                                                                               |
| `rmdir` | remove directory: deletes a directory with the specified name </br></br>**Note:** `rmdir` only works on empty directories                                  | <ul><li>`rmdir folder_name`<ul><li>removes the directory `folder_name` if the directory is empty</li></ul></li><li>`rmdir *`<ul><li>removes all directories within the current directory</li></ul></li></ul>                                                                                                                                                                                                                      |
| `rm`    | remove: deletes file or files with the specified name(s)                                                                                  | <ul><li>`rm file_name`<ul><li>deletes the file `file_name`</li></ul></li><li>`rm *`<ul><li>deletes all files in the current directory</li></ul></li></ul>                                                                                                                                                                                                                                                                            |
| `nano`  | nano text editor: opens the nano text editor </br></br> **Note:** To access the menu options, `^` indicates the control (CTRL) key.                         | <ul><li>`nano`<ul><li>opens the text editor in a blank file</li></ul></li><li>`nano file_name`<ul><li>opens the text editor with `file_name` open. If `file_name` does not exist, it will be created if the file is saved</li></ul></li></ul>                                                                                                                                                                                     |
| `clear` | clear: clears the screen of all input/output                                                                                              | <ul><li>`clear`</li></ul>                                                                                                                                                                                                                                                                                                                                                               |
| `less`  | less: opens an extended view of a file </br></br> **Note:** Use up and down arrows to scroll through the text. To exit the extended view, press '`q`'       | <ul><li>`less <file_name>`<ul><li>opens an extended view of the file `file_name`</li></ul></li></ul>                                                                                                                                                                                                                                                                                                    |
| `cat`   | concatenate: sends file contents to standard input - used frequently with pipes                                                           | <ul><li>`cat <file_name>`<ul><li>prints the contents of the file `file_name`</li></ul></li><li>`cat *.txt`<ul><li>prints the contents of all files in the current directory that end in `.txt`</li></ul></li></ul>                                                                                                                                                                                                                     |
Tutorial Video
--------------

{{< youtube B0VdKiHNjU4 >}}
