+++
title = "Handling Data"
description = "How to work with and transfer data to/from HCC resources."
weight = "30"
+++

{{% panel theme="danger" header="**Sensitive and Protected Data**" %}}HCC currently has *no storage* that is suitable for **HIPAA** or other **PID** data sets.  Users are not permitted to store such data on HCC machines.{{% /panel %}}

{{% notice warning %}}
The Common filesystem will be retiring on June 30th, 2025!!! Any data under `/common` or `$COMMON` will be lost if it is not moved to another location before the retirement. 

It is strongly recommended to begin moving data and updating workflows as soon as possible to avoid lossing data or disrupting workflows. 

More information on the retirement is available on the [Common Retirement FAQ Page]({{< relref "../FAQ/common_retirement" >}}). If you have any questions about the retirement, please email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a>.
{{% /notice %}}

All HCC machines have three separate areas for every user to store data,
each intended for a different purpose. The three areas are `/common`, `/work`, and `/home`, each with different functions. `/home` is your home directory with a quota limit of **{{< hcc-quota "swan.home.block" >}}** and is backed up for best-effort disaster recovery purposes. `/work` is the high performance, I/O focused directory for running jobs. `/work` has a **{{< hcc-quota "swan.work.block" >}} per group quota**, is not backed-up and is subject to a [purge policy]({{<relref "data_storage/#purge-policy" >}}) of **{{< hcc-quota "swan.work.purge" >}} of inactivity on a file**. `/common` works similarly to `/work` and is mounted with read and write capabilities on all HCC clusters, meaning any files on `/common` can be accessed from all of HCC clusters unlike `/home` and `/work` which are cluster dependant. More information on the three storage areas on HCC's clusters are available in the [Data Storage]({{<relref "data_storage">}}) page.
{{< figure src="/images/storage_overview_graphic.png" height="500" class="img-border">}}

HCC also offers a separate, near-line archive with space available for lease called Attic. Attic provides reliable large data storage that is designed to be more reliable than `/work`, and larger than `/home`. More information on Attic and how to transfer data to and from Attic can be found on the [Using Attic]({{<relref "data_storage/using_attic">}}) page.

You can also use your [UNL OneDrive Account]({{< relref "data_transfer/using_rclone_with_hcc/" >}}) account to download and
upload files from any of the HCC clusters.

For moving general data into or out of HCC Resources, users are recommended to use [scp]({{<relref "data_transfer/scp" >}}) for command line transfers on Windows 10, Windows 11, MacOS, and Linux, or for graphical transfers,  [WinSCP]({{<relref "data_transfer/winscp" >}}) for Windows, and [CyberDuck]({{<relref "data_transfer/cyberduck" >}}) for MacOS and Linux

For moving large amounts of data into or out of HCC resources, users are highly encouraged to consider using [Globus Connect]({{< relref "data_transfer/globus_connect/" >}}).


If you have space requirements outside what is currently provided or any questions regarding moving data around,
please
email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a>.

### Using */scratch* storage space to improve running jobs:
[Using Scratch]({{<relref "using_scratch_space" >}})


### Storing public software-specific and research datasets

#### Software-specific datasets
Many software packages available on Swan (e.g., AlphaFold, HUMAnN) require datasets. Where possible, HCC has pre-downloaded the datasets and configured the modules to use the datasets. This avoids any [quota]({{<relref "data_storage">}}) and [purge policy]({{<relref "data_storage/#purge-policy" >}}) issues. 

If you are not sure if a dataset the software requires is already available on Swan, **please check the module info, or email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a> before you attempt to download it yourself**.

#### Research datasets
Many public datasets are commonly used for running jobs across various scientific fields. To avoid any [per-user or per-group quota issues]({{<relref "data_storage">}}), HCC can host these datasets on a system-wide location on Swan excluded from the purge policy, such that the entire HCC community can benefit from using a shared copy.

HCC currently hosts a few public datasets on Swan that can be accessed via data modules:

- **biodata/1.0** - [Static data resources for bioinformatics/computational biology]({{<relref "biodata_module" >}})
- **mldata/1.0** - Static data resources for machine-learning/AI (e.g., ImageNet, TCGA, CAMELYON, TCIA)
- **mridata/1.0** - Static data resources for MRI/NeuroImaging (e.g., Penn Memory Center 3T ASHS 1.0 Atlas)
- **geodata/1.0** - Static data resources for geo data (e.g., NLDAS-2)
- **chemdata/1.0** - Static data resources for computational chemistry (e.g., Tetramers, Zinc)

If you are not sure if a public dataset is already available on Swan, **please check the info of the available data modules (e.g., module help mldata/1.0), or email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a> before you attempt to download the dataset yourself**.

To request a version update of the system-wide available datasets, please email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a>.

{{% notice note %}}
If you have a licensed dataset you want to share with your research group, please email hcc-support@unl.edu for assistance.
{{% /notice %}}

