+++
title = "Data Storage"
description = "How to work with and transfer data to/from HCC resources."
weight = "30"
+++

{{% panel theme="danger" header="**Sensitive and Protected Data**" %}}HCC currently has *no storage* that is suitable for **HIPAA** or other **PID** data sets.  Users are not permitted to store such data on HCC machines.{{% /panel %}}

All HCC machines have three separate areas for every user to store data,
each intended for a different purpose.   In addition, we have a transfer
service that utilizes [Globus Connect]({{< relref "../data_transfer/globus_connect" >}}).
{{< figure src="/images/storage_overview_graphic.png" >}}

---
### Home Directory

{{% notice info %}}
You can access your home directory quickly using the $HOME environmental
variable (i.e. '`cd $HOME'`).
{{% /notice %}}

Your home directory (i.e. `/home/[group]/[username]`) is meant for items
that take up relatively small amounts of space.  For example:  source
code, program binaries, configuration files, etc.  This space is
quota-limited to **{{< hcc-quota "swan.home.block" >}} and {{< hcc-quota "swan.home.inode" >}} files per user**.  The home directories are backed up
for the purposes of best-effort disaster recovery.  This space is not
intended as an area for I/O to active jobs. 

---
### Common Directory

{{% notice warning %}}
The Common filesystem will be retiring on June 30th, 2025!!! Any data under `/common` or `$COMMON` will be lost if it is not moved to another location before the retirement. 

It is strongly recommended to begin moving data and updating workflows as soon as possible to avoid lossing data or disrupting workflows. 

More information on the retirement is available on the [Common Retirement FAQ Page]({{< relref "../../FAQ/common_retirement" >}}). If you have any questions about the retirement, please email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a>.
{{% /notice %}}

{{% notice info %}}
You can access your common directory quickly using the $COMMON
environmental variable (i.e. '`cd $COMMON`')
{{% /notice %}}

The common directory operates similarly to work and is mounted with
**read and write capability to worker nodes all HCC Clusters**. This
means that any files stored in common can be accessed from Swan, making this directory ideal for items that need to be
accessed from multiple clusters such as reference databases and shared
data files.

{{% notice warning %}}
Common is not designed for heavy I/O usage. Please continue to use your
work directory for active job output to ensure the best performance of
your jobs.
{{% /notice %}}

Quotas for common are **{{< hcc-quota "common.block" >}} and {{< hcc-quota "common.inode" >}} files per group**, with larger quotas available
for lease if needed. However, files stored here will **not be backed
up** and are **not subject to purge** at this time. Please continue to
backup your files to prevent irreparable data loss.

Additional information on using the common directories can be found in
the documentation on [Using the /common File System]({{< relref "using_the_common_file_system" >}})

---
### High Performance Work Directory

{{% notice info %}}
You can access your work directory quickly using the $WORK environmental
variable (i.e. '`cd $WORK'`).
{{% /notice %}}

{{% panel theme="danger" header="**File Loss**" %}}The `/work` directories are **not backed up**. Irreparable data loss is possible with a mis-typed command. See [Preventing File Loss]({{< relref "preventing_file_loss" >}}) for strategies to avoid this.{{% /panel %}}

Every user has a corresponding directory under /work using the same
naming convention as `/home` (i.e. `/work/[group]/[username]`).  We
encourage all users to use this space for I/O to running jobs.  This
directory can also be used when larger amounts of space are temporarily
needed.  There is a **{{< hcc-quota "swan.work.block" >}} and {{< hcc-quota "swan.work.inode" >}} files per group quota**; space in /work is shared
among all users.  It should be treated as short-term scratch space, and
**is not backed up**.  **Please use the `hcc-du` command to check your
own and your group's usage, and back up and clean up your files at
reasonable intervals in $WORK.**

---
### Purge Policy

HCC has a **purge policy on /work** for files that become dormant.
 After **{{< hcc-quota "swan.work.purge" >}} of inactivity on a file**, an automated
purge process will reclaim the used space of these dormant files.  HCC
provides the **`hcc-purge`** utility to list both the summary and the
actual file paths of files that have been dormant for **24 weeks**.
 This list is periodically generated; the timestamp of the last search
is included in the default summary output when calling `hcc-purge` with
no arguments.  No output from `hcc-purge` indicates the last scan did
not find any dormant files.  `hcc-purge -l` will use the less pager to
list the matching files for the user.  The candidate list can also be
accessed at the following path:` /lustre/purge/current/${USER}.list`.
 This list is updated twice a week, on Mondays and Thursdays.

{{% notice warning %}}
`/work` is intended for recent job output and not long term storage. Evidence of circumventing the purge policy by users will result in consequences including account lockout.
{{% /notice %}}

If you have space requirements outside what is currently provided,
please
email <a href="mailto:hcc-support@unl.edu" class="external-link">hcc-support@unl.edu</a> and
we will gladly discuss alternatives.

---
### [Attic]({{< relref "using_attic" >}})

Attic is a near line archive available for lease at HCC.  Attic
provides reliable large data storage that is designed to be more
reliable then `/work`, and larger than `/home`. Access to Attic is done
through [Globus Connect]({{< relref "../data_transfer/globus_connect" >}}).

More details on Attic can be found on HCC's
<a href="https://hcc.unl.edu/attic" class="external-link">Attic</a>
website.

---
### [Globus Connect]({{< relref "../data_transfer/globus_connect" >}})

For moving large amounts of data into or out of HCC resources, users are
highly encouraged to consider using [Globus
Connect]({{< relref "../data_transfer/globus_connect" >}}).

---
### Using Box

You can use your [UNL
Box.com]({{< relref "integrating_box_with_hcc" >}}) account to download and
upload files from any of the HCC clusters.


