+++
title = "Integrating Box with HCC"
description = "How to integrate Box with HCC"
weight = 50
+++

{{% notice warning %}}
NU no longer has an active arrangement with <a href="https://www.box.com/" class="external-link">Box.com</a>
and has migrated to Microsoft 365 services. Please visit our page on [using rclone for file transfer]({{< relref "using_rclone_with_hcc" >}})
or [using OneDrive with Globus]({{< relref "activating_unl_onedrive" >}}) (UNL only) for instructions on how to access your NU Microsoft 365 storage from HCC resources.
{{% /notice %}}

The instructions below remain as a reference for use with personal or other institutional Box accounts.

---
### Step-by-step guide for Lftp

1.  Login to your institution or personal Box account.

2.  Since we are going to be using [ftps](https://en.wikipedia.org/wiki/FTPS) protocol to access your [Box.com](https://www.box.com/) storage, you need to create an **External Password**.  In the Box.com interface, you can create it at **Account Settings > Account > Authentication > Create Password.**
{{< figure src="/images/box_create_external_password.png" class="img-border" >}}

3.  After logging into the cluster of your choice, load the `lftp` module by entering the command below at the prompt:
{{% panel theme="info" header="Load the lftp module" %}}
{{< highlight bash >}}
module load lftp
{{< /highlight >}}
{{% /panel %}}

4.  Connect to Box using your full email as the username and external password you created:
{{% panel theme="info" header="Connect to Box" %}}
{{< highlight bash >}}
lftp -u <username> ftps://ftp.box.com
Password: <password>
{{< /highlight >}}
{{% /panel %}}
{{% notice info%}}
  Be sure to use your fully qualified username; that is, include the domain.  For example, `hhusker2@example.edu`.
{{% /notice %}}

5.  Test the connection by running the `ls` command.  You should see a listing of your Box files.  Assuming it works, add a bookmark named "box" to use when connecting later. Optionally run `set bmk:save-passwords yes` first if you want lftp to remember the password:
{{% panel theme="info" header="Add lftp bookmark" %}}
{{< highlight bash >}}
lftp demo2@example.edu@ftp.box.com:/> set bmk:save-passwords yes
lftp demo2@example.edu@ftp.box.com:/> bookmark add box
{{< /highlight >}}
{{% /panel %}}

6.  Exit `lftp` by typing `quit`.  To reconnect later, use bookmark name:
{{% panel theme="info" header="Connect using bookmark name" %}}
{{< highlight bash >}}
lftp box
{{< /highlight >}}
{{% /panel %}}

7.  To upload or download files, use `get` and `put` commands.  For example:
{{% panel theme="info" header="Transferring files" %}}
{{< highlight bash >}}
[demo2@login.swan ~]$ lftp box
lftp demo2@example.edu@ftp.box.com:/> put myfile.txt
lftp demo2@example.edu@ftp.box.com:/> get my_other_file.txt
{{< /highlight >}}
{{% /panel %}}

8.  To download directories, use the `mirror` command.  To upload directories, use the `mirror` command with the `-R` option.  For example, to download a directory named `my_box-dir` to your current directory:
{{% panel theme="info" header="Download a directory from Box" %}}
{{< highlight bash >}}
[demo2@login.swan ~]$ lftp box
lftp demo2@example.edu@ftp.box.com:/> mirror my_box_dir
{{< /highlight >}}
{{% /panel %}}
To upload a directory named `my_hcc_dir` to Box, use `mirror` with the `-R` option:
{{% panel theme="info" header="Upload a directory to Box" %}}
{{< highlight bash >}}
[demo2@login.swan ~]$ lftp box
lftp demo2@example.edu@ftp.box.com:/> mirror -R my_hcc_dir
{{< /highlight >}}
{{% /panel %}}

9.  Lftp also supports using scripts to transfer files.  This can be used to automatically download or upload files during jobs.  For example, create a file called "transfer.sh" with the following lines:
{{% panel theme="info" header="transfer.sh" %}}
{{< highlight bash >}}
open box
get some_input_file.tar.gz
put my_output_file.tar.gz
{{< /highlight >}}
{{% /panel %}}
To run this script, do:
{{% panel theme="info" header="Run transfer.sh" %}}
{{< highlight bash >}}
module load lftp
lftp -f transfer.sh
{{< /highlight >}}
{{% /panel %}}
